@@ -58,7 +58,8 @@ extern "C" {
 extern unsigned long long Pagesize;
 extern unsigned long long Mmap_align;
 
-#if defined(__x86_64) || defined(_M_X64) || defined(__aarch64__)
+#if defined(__x86_64) || defined(_M_X64) || defined(__aarch64__) || \
+	defined(__riscv)
 #define CACHELINE_SIZE 64ULL
 #elif defined(__PPC64__)
 #define CACHELINE_SIZE 128ULL
@@ -96,7 +97,7 @@ int util_compare_file_inodes(const char *path1, const char *path2);
 int util_tmpfile(const char *dir, const char *templ, int flags);
 void *util_aligned_malloc(size_t alignment, size_t size);
 void util_aligned_free(void *ptr);
-struct tm *util_localtime(const time_t *timep);
+struct tm *util_localtime(const time_t *timep, struct tm *tm);
 int util_safe_strcpy(char *dst, const char *src, size_t max_length);
 void util_emit_log(const char *lib, const char *func, int order);
 char *util_readline(FILE *fh);
@@ -134,13 +135,24 @@ void util_set_alloc_funcs(
 #ifdef _MSC_VER
 #define force_inline inline __forceinline
 #define NORETURN __declspec(noreturn)
-#define barrier() _ReadWriteBarrier()
 #else
 #define force_inline __attribute__((always_inline)) inline
 #define NORETURN __attribute__((noreturn))
-#define barrier() asm volatile("" ::: "memory")
 #endif
 
+/*
+ * compiler_barrier -- issues a compiler barrier
+ */
+static force_inline void
+compiler_barrier(void)
+{
+#ifdef _MSC_VER
+	_ReadWriteBarrier();
+#else
+	asm volatile("" ::: "memory");
+#endif
+}
+
 #ifdef _MSC_VER
 typedef UNALIGNED uint64_t ua_uint64_t;
 typedef UNALIGNED uint32_t ua_uint32_t;
@@ -535,6 +547,28 @@ static
 #define CHECK_FUNC_COMPATIBLE(func1, func2) do {} while (0)
 #endif /* __GNUC__ */
 
+/* macro for counting the number of varargs (up to 9) */
+#define COUNT(...)\
+	COUNT_I(__VA_ARGS__, 9, 8, 7, 6, 5, 4, 3, 2, 1)
+#define COUNT_I(_, _9, _8, _7, _6, _5, _4, _3, _2,  X, ...) X
+
+/* concatenation macro */
+#define GLUE(A, B) GLUE_I(A, B)
+#define GLUE_I(A, B) A##B
+
+/* macro for suppresing errors from unused variables (up to 9) */
+#define SUPPRESS_UNUSED(...)\
+	GLUE(SUPPRESS_ARG_, COUNT(__VA_ARGS__))(__VA_ARGS__)
+#define SUPPRESS_ARG_1(X) (void) X
+#define SUPPRESS_ARG_2(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_1(__VA_ARGS__)
+#define SUPPRESS_ARG_3(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_2(__VA_ARGS__)
+#define SUPPRESS_ARG_4(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_3(__VA_ARGS__)
+#define SUPPRESS_ARG_5(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_4(__VA_ARGS__)
+#define SUPPRESS_ARG_6(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_5(__VA_ARGS__)
+#define SUPPRESS_ARG_7(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_6(__VA_ARGS__)
+#define SUPPRESS_ARG_8(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_7(__VA_ARGS__)
+#define SUPPRESS_ARG_9(X, ...) SUPPRESS_ARG_1(X); SUPPRESS_ARG_8(__VA_ARGS__)
+
 #ifdef __cplusplus
 }
 #endif
