@@ -1,34 +1,5 @@
-/*
- * Copyright 2014-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2014-2021, Intel Corporation */
 
 /*
  * obj.c -- transactional object store implementation
@@ -93,6 +64,7 @@ static struct critnib *pools_ht; /* hash table used for searching by UUID */
 static struct critnib *pools_tree; /* tree used for searching by address */
 
 int _pobj_cache_invalidate;
+static os_mutex_t pools_mutex;
 
 #ifndef _WIN32
 
@@ -296,6 +268,8 @@ obj_init(void)
 
 	COMPILE_ERROR_ON(PMEMOBJ_F_MEM_NOFLUSH != PMEM_F_MEM_NOFLUSH);
 
+	os_mutex_init(&pools_mutex);
+
 #ifdef _WIN32
 	/* XXX - temporary implementation (see above) */
 	os_once(&Cached_pool_key_once, _Cached_pool_key_alloc);
@@ -305,6 +279,7 @@ obj_init(void)
 	 * subsequent call to this function for individual pools.
 	 */
 	ctl_global_register();
+	pmalloc_global_ctl_register();
 
 	if (obj_ctl_init_and_load(NULL))
 		FATAL("error: %s", pmemobj_errormsg());
@@ -331,6 +306,8 @@ obj_fini(void)
 	lane_info_destroy();
 	util_remote_fini();
 
+	os_mutex_destroy(&pools_mutex);
+
 #ifdef _WIN32
 	(void) os_tls_key_delete(Cached_pool_key);
 #endif
@@ -345,6 +322,17 @@ obj_drain_empty(void)
 	/* do nothing */
 }
 
+/*
+ * obj_msync_nofail -- (internal) pmem_msync wrapper that never fails from
+ * caller's perspective
+ */
+static void
+obj_msync_nofail(const void *addr, size_t size)
+{
+	if (pmem_msync(addr, size))
+		FATAL("!pmem_msync");
+}
+
 /*
  * obj_nopmem_memcpy -- (internal) memcpy followed by an msync
  */
@@ -360,7 +348,7 @@ obj_nopmem_memcpy(void *dest, const void *src, size_t len, unsigned flags)
 	 * libc memcpy does not.
 	 */
 	pmem_memcpy(dest, src, len, PMEM_F_MEM_NOFLUSH);
-	pmem_msync(dest, len);
+	obj_msync_nofail(dest, len);
 	return dest;
 }
 
@@ -374,7 +362,7 @@ obj_nopmem_memmove(void *dest, const void *src, size_t len, unsigned flags)
 
 	/* see comment in obj_nopmem_memcpy */
 	pmem_memmove(dest, src, len, PMEM_F_MEM_NOFLUSH);
-	pmem_msync(dest, len);
+	obj_msync_nofail(dest, len);
 	return dest;
 }
 
@@ -388,7 +376,7 @@ obj_nopmem_memset(void *dest, int c, size_t len, unsigned flags)
 
 	/* see comment in obj_nopmem_memcpy */
 	pmem_memset(dest, c, len, PMEM_F_MEM_NOFLUSH);
-	pmem_msync(dest, len);
+	obj_msync_nofail(dest, len);
 	return dest;
 }
 
@@ -476,6 +464,9 @@ obj_norep_memset(void *ctx, void *dest, int c, size_t len, unsigned flags)
 static int
 obj_norep_persist(void *ctx, const void *addr, size_t len, unsigned flags)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(flags);
+
 	PMEMobjpool *pop = ctx;
 	LOG(15, "pop %p addr %p len %zu", pop, addr, len);
 
@@ -490,6 +481,9 @@ obj_norep_persist(void *ctx, const void *addr, size_t len, unsigned flags)
 static int
 obj_norep_flush(void *ctx, const void *addr, size_t len, unsigned flags)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(flags);
+
 	PMEMobjpool *pop = ctx;
 	LOG(15, "pop %p addr %p len %zu", pop, addr, len);
 
@@ -829,7 +823,7 @@ obj_vg_check_no_undef(struct pmemobjpool *pop)
 static void
 obj_vg_boot(struct pmemobjpool *pop)
 {
-	if (!On_valgrind)
+	if (!On_memcheck)
 		return;
 
 	LOG(4, "pop %p", pop);
@@ -994,17 +988,6 @@ obj_descr_check(PMEMobjpool *pop, const char *layout, size_t poolsize)
 	return 0;
 }
 
-/*
- * obj_msync_nofail -- (internal) pmem_msync wrapper that never fails from
- * caller's perspective
- */
-static void
-obj_msync_nofail(const void *addr, size_t size)
-{
-	if (pmem_msync(addr, size))
-		FATAL("!pmem_msync");
-}
-
 /*
  * obj_replica_init_local -- (internal) initialize runtime part
  *                               of the local replicas
@@ -1059,6 +1042,9 @@ static int
 obj_replica_init_remote(PMEMobjpool *rep, struct pool_set *set,
 				unsigned repidx, int create)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(create);
+
 	LOG(3, "rep %p set %p repidx %u", rep, set, repidx);
 
 	struct pool_replica *repset = set->replica[repidx];
@@ -1236,7 +1222,7 @@ obj_runtime_init(PMEMobjpool *pop, int rdonly, int boot, unsigned nlanes)
 			goto err_boot;
 
 #if VG_MEMCHECK_ENABLED
-		if (On_valgrind) {
+		if (On_memcheck) {
 			/* mark unused part of the pool as not accessible */
 			void *end = palloc_heap_end(&pop->heap);
 			VALGRIND_DO_MAKE_MEM_NOACCESS(end,
@@ -1352,6 +1338,8 @@ pmemobj_createU(const char *path, const char *layout,
 		return NULL;
 	}
 
+	os_mutex_lock(&pools_mutex);
+
 	/*
 	 * A number of lanes available at runtime equals the lowest value
 	 * from all reported by remote replicas hosts. In the single host mode
@@ -1373,6 +1361,7 @@ pmemobj_createU(const char *path, const char *layout,
 			PMEMOBJ_MIN_PART, &adj_pool_attr, &runtime_nlanes,
 			REPLICAS_ENABLED) != 0) {
 		LOG(2, "cannot create pool or pool set");
+		os_mutex_unlock(&pools_mutex);
 		return NULL;
 	}
 
@@ -1426,6 +1415,7 @@ pmemobj_createU(const char *path, const char *layout,
 	util_poolset_fdclose(set);
 
 	LOG(3, "pop %p", pop);
+	os_mutex_unlock(&pools_mutex);
 
 	return pop;
 
@@ -1435,6 +1425,7 @@ err:
 	if (set->remote)
 		obj_cleanup_remote(pop);
 	util_poolset_close(set, DELETE_CREATED_PARTS);
+	os_mutex_unlock(&pools_mutex);
 	errno = oerrno;
 	return NULL;
 }
@@ -1736,6 +1727,8 @@ obj_open_common(const char *path, const char *layout, unsigned flags, int boot)
 	PMEMobjpool *pop = NULL;
 	struct pool_set *set;
 
+	os_mutex_lock(&pools_mutex);
+
 	/*
 	 * A number of lanes available at runtime equals the lowest value
 	 * from all reported by remote replicas hosts. In the single host mode
@@ -1744,8 +1737,10 @@ obj_open_common(const char *path, const char *layout, unsigned flags, int boot)
 	 * environment variable whichever is lower.
 	 */
 	unsigned runtime_nlanes = obj_get_nlanes();
-	if (obj_pool_open(&set, path, flags, &runtime_nlanes))
+	if (obj_pool_open(&set, path, flags, &runtime_nlanes)) {
+		os_mutex_unlock(&pools_mutex);
 		return NULL;
+	}
 
 	/* pop is master replica from now on */
 	pop = set->replica[0]->part[0].addr;
@@ -1798,6 +1793,7 @@ obj_open_common(const char *path, const char *layout, unsigned flags, int boot)
 #endif
 
 	util_poolset_fdclose(set);
+	os_mutex_unlock(&pools_mutex);
 
 	LOG(3, "pop %p", pop);
 
@@ -1810,6 +1806,7 @@ err_descr_check:
 	obj_replicas_fini(set);
 replicas_init:
 	obj_pool_close(set);
+	os_mutex_unlock(&pools_mutex);
 	return NULL;
 }
 
@@ -1970,7 +1967,7 @@ pmemobj_close(PMEMobjpool *pop)
 	LOG(3, "pop %p", pop);
 	PMEMOBJ_API_START();
 
-	_pobj_cache_invalidate++;
+	os_mutex_lock(&pools_mutex);
 
 	if (critnib_remove(pools_ht, pop->uuid_lo) != pop) {
 		ERR("critnib_remove for pools_ht");
@@ -1998,7 +1995,12 @@ pmemobj_close(PMEMobjpool *pop)
 
 #endif /* _WIN32 */
 
+	VALGRIND_HG_DRD_DISABLE_CHECKING(&_pobj_cache_invalidate,
+		sizeof(_pobj_cache_invalidate));
+	_pobj_cache_invalidate++;
+
 	obj_pool_cleanup(pop);
+	os_mutex_unlock(&pools_mutex);
 	PMEMOBJ_API_END();
 }
 
@@ -3436,6 +3438,9 @@ pmemobj_ctl_execW(PMEMobjpool *pop, const wchar_t *name, void *arg)
 void
 _pobj_debug_notice(const char *api_name, const char *file, int line)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(api_name, file, line);
+
 #ifdef DEBUG
 	if (pmemobj_tx_stage() != TX_STAGE_NONE) {
 		if (file)
@@ -3465,12 +3470,12 @@ void
 pmemobj_inject_fault_at(enum pmem_allocation_type type, int nth,
 							const char *at)
 {
-	common_inject_fault_at(type, nth, at);
+	core_inject_fault_at(type, nth, at);
 }
 
 int
 pmemobj_fault_injection_enabled(void)
 {
-	return common_fault_injection_enabled();
+	return core_fault_injection_enabled();
 }
 #endif
