@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2018, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2021, Intel Corporation */
 
 /*
  * check_pool_hdr.c -- pool header check
@@ -93,7 +64,7 @@ pool_hdr_valid(struct pool_hdr *hdrp)
 {
 	return !util_is_zeroed((void *)hdrp, sizeof(*hdrp)) &&
 		util_checksum(hdrp, sizeof(*hdrp), &hdrp->checksum, 0,
-			POOL_HDR_CSUM_END_OFF);
+			POOL_HDR_CSUM_END_OFF(hdrp));
 }
 
 /*
@@ -107,8 +78,6 @@ pool_supported(enum pool_type type)
 		return 1;
 	case POOL_TYPE_BLK:
 		return 1;
-	case POOL_TYPE_CTO:
-		return 1;
 	case POOL_TYPE_OBJ:
 	default:
 		return 0;
@@ -202,25 +171,27 @@ pool_hdr_default_check(PMEMpoolcheck *ppc, location *loc)
 			"to default value 0x%x?", loc->prefix, def_hdr.major);
 	}
 
-	if (loc->hdr.compat_features != def_hdr.compat_features) {
+	features_t unknown = util_get_unknown_features(
+			loc->hdr.features, def_hdr.features);
+	if (unknown.compat) {
 		CHECK_ASK(ppc, Q_DEFAULT_COMPAT_FEATURES,
-			"%spool_hdr.compat_features is not valid.|Do you want "
+			"%spool_hdr.features.compat is not valid.|Do you want "
 			"to set it to default value 0x%x?", loc->prefix,
-			def_hdr.compat_features);
+			def_hdr.features.compat);
 	}
 
-	if (loc->hdr.incompat_features != def_hdr.incompat_features) {
+	if (unknown.incompat) {
 		CHECK_ASK(ppc, Q_DEFAULT_INCOMPAT_FEATURES,
-			"%spool_hdr.incompat_features is not valid.|Do you "
+			"%spool_hdr.features.incompat is not valid.|Do you "
 			"want to set it to default value 0x%x?", loc->prefix,
-			def_hdr.incompat_features);
+			def_hdr.features.incompat);
 	}
 
-	if (loc->hdr.ro_compat_features != def_hdr.ro_compat_features) {
+	if (unknown.ro_compat) {
 		CHECK_ASK(ppc, Q_DEFAULT_RO_COMPAT_FEATURES,
-			"%spool_hdr.ro_compat_features is not valid.|Do you "
+			"%spool_hdr.features.ro_compat is not valid.|Do you "
 			"want to set it to default value 0x%x?", loc->prefix,
-			def_hdr.ro_compat_features);
+			def_hdr.features.ro_compat);
 	}
 
 	if (!util_is_zeroed(loc->hdr.unused, sizeof(loc->hdr.unused))) {
@@ -239,6 +210,9 @@ static int
 pool_hdr_default_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	void *context)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(context);
+
 	LOG(3, NULL);
 
 	ASSERTne(loc, NULL);
@@ -258,19 +232,19 @@ pool_hdr_default_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 		loc->hdr.major = def_hdr.major;
 		break;
 	case Q_DEFAULT_COMPAT_FEATURES:
-		CHECK_INFO(ppc, "%ssetting pool_hdr.compat_features to 0x%x",
-			loc->prefix, def_hdr.compat_features);
-		loc->hdr.compat_features = def_hdr.compat_features;
+		CHECK_INFO(ppc, "%ssetting pool_hdr.features.compat to 0x%x",
+			loc->prefix, def_hdr.features.compat);
+		loc->hdr.features.compat = def_hdr.features.compat;
 		break;
 	case Q_DEFAULT_INCOMPAT_FEATURES:
-		CHECK_INFO(ppc, "%ssetting pool_hdr.incompat_features to 0x%x",
-			loc->prefix, def_hdr.incompat_features);
-		loc->hdr.incompat_features = def_hdr.incompat_features;
+		CHECK_INFO(ppc, "%ssetting pool_hdr.features.incompat to 0x%x",
+			loc->prefix, def_hdr.features.incompat);
+		loc->hdr.features.incompat = def_hdr.features.incompat;
 		break;
 	case Q_DEFAULT_RO_COMPAT_FEATURES:
-		CHECK_INFO(ppc, "%ssetting pool_hdr.ro_compat_features to 0x%x",
-			loc->prefix, def_hdr.ro_compat_features);
-		loc->hdr.ro_compat_features = def_hdr.ro_compat_features;
+		CHECK_INFO(ppc, "%ssetting pool_hdr.features.ro_compat to 0x%x",
+			loc->prefix, def_hdr.features.ro_compat);
+		loc->hdr.features.ro_compat = def_hdr.features.ro_compat;
 		break;
 	case Q_ZERO_UNUSED_AREA:
 		CHECK_INFO(ppc, "%ssetting pool_hdr.unused to zeros",
@@ -290,6 +264,9 @@ pool_hdr_default_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 static int
 pool_hdr_quick_check(PMEMpoolcheck *ppc, location *loc)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ppc);
+
 	LOG(3, NULL);
 	if (pool_hdr_valid(loc->hdrp))
 		loc->step = CHECK_STEP_COMPLETE;
@@ -306,7 +283,7 @@ pool_hdr_nondefault(PMEMpoolcheck *ppc, location *loc)
 	LOG(3, NULL);
 
 	if (loc->hdr.crtime > (uint64_t)ppc->pool->set_file->mtime) {
-		const char *error = "%spool_hdr.crtime is not valid";
+		const char * const error = "%spool_hdr.crtime is not valid";
 		if (CHECK_IS_NOT(ppc, REPAIR)) {
 			ppc->result = CHECK_RESULT_NOT_CONSISTENT;
 			return CHECK_ERR(ppc, error, loc->prefix);
@@ -326,7 +303,7 @@ pool_hdr_nondefault(PMEMpoolcheck *ppc, location *loc)
 			memcmp(&loc->valid_part_hdrp->arch_flags,
 				&loc->hdr.arch_flags,
 				sizeof(struct arch_flags)) != 0) {
-		const char *error = "%spool_hdr.arch_flags is not valid";
+		const char * const error = "%spool_hdr.arch_flags is not valid";
 		if (CHECK_IS_NOT(ppc, REPAIR)) {
 			ppc->result = CHECK_RESULT_NOT_CONSISTENT;
 			return CHECK_ERR(ppc, error, loc->prefix);
@@ -347,6 +324,9 @@ static int
 pool_hdr_nondefault_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	void *context)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(context);
+
 	LOG(3, NULL);
 
 	ASSERTne(loc, NULL);
@@ -506,6 +486,9 @@ static int
 pool_hdr_poolset_uuid_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	void *context)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(context);
+
 	LOG(3, NULL);
 
 	ASSERTne(loc, NULL);
@@ -634,6 +617,9 @@ static int
 pool_hdr_uuid_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	void *context)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(context);
+
 	LOG(3, NULL);
 
 	ASSERTne(loc, NULL);
@@ -719,6 +705,9 @@ static int
 pool_hdr_uuid_links_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	void *context)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(context);
+
 	LOG(3, NULL);
 
 	ASSERTne(loc, NULL);
@@ -791,6 +780,9 @@ static int
 pool_hdr_checksum_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	void *context)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(context);
+
 	LOG(3, NULL);
 
 	ASSERTne(loc, NULL);
@@ -798,7 +790,7 @@ pool_hdr_checksum_fix(PMEMpoolcheck *ppc, location *loc, uint32_t question,
 	switch (question) {
 	case Q_CHECKSUM:
 		util_checksum(&loc->hdr, sizeof(loc->hdr), &loc->hdr.checksum,
-			1, POOL_HDR_CSUM_END_OFF);
+			1, POOL_HDR_CSUM_END_OFF(&loc->hdr));
 		CHECK_INFO(ppc, "%ssetting pool_hdr.checksum to 0x%jx",
 			loc->prefix, le64toh(loc->hdr.checksum));
 		break;
@@ -875,6 +867,9 @@ static int
 step_exe(PMEMpoolcheck *ppc, const struct step *steps, location *loc,
 	struct pool_replica *rep, unsigned nreplicas)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(nreplicas);
+
 	const struct step *step = &steps[loc->step++];
 
 	if (!step->fix)
@@ -912,10 +907,10 @@ init_location_data(PMEMpoolcheck *ppc, location *loc)
 	unsigned nfiles = pool_set_files_count(ppc->pool->set_file);
 	if (ppc->result != CHECK_RESULT_PROCESS_ANSWERS) {
 		if (nfiles > 1) {
-			int ret = snprintf(loc->prefix, PREFIX_MAX_SIZE,
+			int ret = util_snprintf(loc->prefix, PREFIX_MAX_SIZE,
 				"replica %u part %u: ",
 				loc->replica, loc->part);
-			if (ret < 0 || ret >= PREFIX_MAX_SIZE)
+			if (ret < 0)
 				FATAL("!snprintf");
 		} else
 			loc->prefix[0] = '\0';
