@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2020-2022, Intel Corporation */
 
 /*
  * pmem_memset.c -- unit test for doing a memset
@@ -18,7 +18,8 @@ do_memset_variants(int fd, char *dest, const char *file_name, size_t dest_off,
 {
 	for (int i = 0; i < ARRAY_SIZE(Flags); ++i) {
 		do_memset(fd, dest, file_name, dest_off, bytes,
-				fn, Flags[i], p);
+				fn, Flags[i], p,
+				NULL, NULL, NULL);
 		if (Flags[i] & PMEMOBJ_F_MEM_NOFLUSH)
 			p(dest, bytes);
 	}
@@ -39,12 +40,14 @@ main(int argc, char *argv[])
 	const char *thr = os_getenv("PMEM_MOVNT_THRESHOLD");
 	const char *avx = os_getenv("PMEM_AVX");
 	const char *avx512f = os_getenv("PMEM_AVX512F");
+	const char *movdir64b = os_getenv("PMEM_MOVDIR64B");
 
-	START(argc, argv, "pmem2_memset %s %s %s %savx %savx512f",
+	START(argc, argv, "pmem2_memset %s %s %s %savx %savx512f %smovdir64b",
 			argv[2], argv[3],
 			thr ? thr : "default",
 			avx ? "" : "!",
-			avx512f ? "" : "!");
+			avx512f ? "" : "!",
+			movdir64b ? "" : "!");
 
 	fd = OPEN(argv[1], O_RDWR);
 
