@@ -42,41 +42,29 @@ class TEST0(PmemsetMemset):
     pass
 
 
-@t.require_architectures('x86_64')
-@t.add_params('wc_workaround', ['on', 'off', 'default'])
-class TEST1(PmemsetMemset):
-    envs0 = ("PMEM_AVX512F",)
-
-
-@t.require_architectures('x86_64')
-@t.add_params('wc_workaround', ['on', 'off', 'default'])
-class TEST2(PmemsetMemset):
-    envs0 = ("PMEM_AVX512F", "PMEM_AVX",)
-
-
 @t.add_params('wc_workaround', ['default'])
-class TEST3(PmemsetMemset):
+class TEST1(PmemsetMemset):
     envs1 = ("PMEM_NO_MOVNT",)
 
 
 @t.add_params('wc_workaround', ['default'])
-class TEST4(PmemsetMemset):
+class TEST2(PmemsetMemset):
     envs1 = ("PMEM_NO_MOVNT", "PMEM_NO_GENERIC_MEMCPY")
 
 
+@t.require_architectures('x86_64')
+@t.add_params('wc_workaround', ['on', 'off', 'default'])
+class TEST3(PmemsetMemset):
+    envs0 = ("PMEM_AVX512F",)
+
+
+@t.require_architectures('x86_64')
+@t.add_params('wc_workaround', ['on', 'off', 'default'])
+class TEST4(PmemsetMemset):
+    envs0 = ("PMEM_AVX512F", "PMEM_AVX",)
+
+
 @t.require_architectures('x86_64')
 @t.add_params('wc_workaround', ['on', 'off', 'default'])
 class TEST5(PmemsetMemset):
-    envs0 = ("PMEM_MOVDIR64B",)
-
-
-@t.require_architectures('x86_64')
-@t.add_params('wc_workaround', ['on', 'off', 'default'])
-class TEST6(PmemsetMemset):
-    envs0 = ("PMEM_MOVDIR64B", "PMEM_AVX512F",)
-
-
-@t.require_architectures('x86_64')
-@t.add_params('wc_workaround', ['on', 'off', 'default'])
-class TEST7(PmemsetMemset):
-    envs0 = ("PMEM_MOVDIR64B", "PMEM_AVX512F", "PMEM_AVX",)
+    envs1 = ("PMEM_MOVDIR64B",)
