@@ -1,34 +1,5 @@
-/*
- * Copyright 2014-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2014-2021, Intel Corporation */
 
 /*
  * common.c -- definitions of common functions
@@ -65,7 +36,7 @@
 #include "out.h"
 #include "mmap.h"
 #include "util_pmem.h"
-#include "badblock.h"
+#include "set_badblocks.h"
 #include "util.h"
 
 #define REQ_BUFF_SIZE	2048U
@@ -1001,54 +972,59 @@ util_opt_print_requirements(const struct options *opts,
 		&opts->opts[util_opt_get_index(opts, req->opt)];
 	int sn;
 
-	sn = snprintf(&buff[n], REQ_BUFF_SIZE - n,
+	sn = util_snprintf(&buff[n], REQ_BUFF_SIZE - n,
 			"option [-%c|--%s] requires: ", opt->val, opt->name);
 	assert(sn >= 0);
-	if (sn >= 0)
-		n += (unsigned)sn;
+	n += (unsigned)sn;
+	if (n >= REQ_BUFF_SIZE)
+		goto exit;
 
 	size_t rc = 0;
 	while ((tmp = req->req) != 0) {
 		if (rc != 0) {
-			sn = snprintf(&buff[n], REQ_BUFF_SIZE - n, " and ");
+			sn = util_snprintf(&buff[n], REQ_BUFF_SIZE - n,
+					" and ");
 			assert(sn >= 0);
-			if (sn >= 0)
-				n += (unsigned)sn;
+			n += (unsigned)sn;
+			if (n >= REQ_BUFF_SIZE)
+				break;
 		}
 
 		size_t c = 0;
 		while (tmp) {
-			if (c == 0)
-				sn = snprintf(&buff[n], REQ_BUFF_SIZE - n, "[");
-			else
-				sn = snprintf(&buff[n], REQ_BUFF_SIZE - n, "|");
+			sn = util_snprintf(&buff[n], REQ_BUFF_SIZE - n,
+					c == 0 ? "[" : "|");
 			assert(sn >= 0);
-			if (sn >= 0)
-				n += (unsigned)sn;
+			n += (unsigned)sn;
+			if (n >= REQ_BUFF_SIZE)
+				break;
 
 			int req_opt_ind =
 				util_opt_get_index(opts, tmp & OPT_REQ_MASK);
 			const struct option *req_option =
 				&opts->opts[req_opt_ind];
 
-			sn = snprintf(&buff[n], REQ_BUFF_SIZE - n,
+			sn = util_snprintf(&buff[n], REQ_BUFF_SIZE - n,
 				"-%c|--%s", req_option->val, req_option->name);
 			assert(sn >= 0);
-			if (sn >= 0)
-				n += (unsigned)sn;
+			n += (unsigned)sn;
+			if (n >= REQ_BUFF_SIZE)
+				break;
 
 			tmp >>= OPT_REQ_SHIFT;
 			c++;
 		}
-		sn = snprintf(&buff[n], REQ_BUFF_SIZE - n, "]");
+		sn = util_snprintf(&buff[n], REQ_BUFF_SIZE - n, "]");
 		assert(sn >= 0);
-		if (sn >= 0)
-			n += (unsigned)sn;
+		n += (unsigned)sn;
+		if (n >= REQ_BUFF_SIZE)
+			break;
 
 		req++;
 		rc++;
 	}
 
+exit:
 	outv_err("%s\n", buff);
 }
 
