@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2022, Intel Corporation */
 
 /*
  * rpmemd_config.c -- rpmemd config source file
@@ -100,6 +71,10 @@ static const struct option options[] = {
 
 static const char * const help_str =
 "\n"
+"WARNING: rpmemd is deprecated since PMDK 1.12 release.\n"
+"If you are interested in a remote persistent\n"
+"memory support please look at new library **rpma** https://github.com/pmem/rpma.\n"
+"\n"
 "Options:\n"
 "  -c, --config <path>           configuration file location\n"
 "  -r, --remove <poolset>        remove pool described by given poolset file\n"
@@ -522,18 +497,18 @@ get_home_dir(char *str, size_t size)
 {
 	char *home = os_getenv(HOME_ENV);
 	if (home) {
-		int r = snprintf(str, size, "%s", home);
+		int r = util_snprintf(str, size, "%s", home);
 		if (r < 0)
-			RPMEMD_FATAL("snprintf: %d", r);
+			RPMEMD_FATAL("!snprintf");
 	} else {
 		uid_t uid = getuid();
 		struct passwd *pw = getpwuid(uid);
 		if (pw == NULL)
 			RPMEMD_FATAL("!getpwuid");
 
-		int r = snprintf(str, size, "%s", pw->pw_dir);
+		int r = util_snprintf(str, size, "%s", pw->pw_dir);
 		if (r < 0)
-			RPMEMD_FATAL("snprintf: %d", r);
+			RPMEMD_FATAL("!snprintf");
 	}
 }
 
@@ -545,9 +520,9 @@ static void
 concat_dir_and_file_name(char *path, size_t size, const char *dir,
 	const char *file)
 {
-	int r = snprintf(path, size, "%s/%s", dir, file);
+	int r = util_snprintf(path, size, "%s/%s", dir, file);
 	if (r < 0)
-		RPMEMD_FATAL("snprintf: %d", r);
+		RPMEMD_FATAL("!snprintf");
 }
 
 /*
@@ -578,10 +553,10 @@ str_replace_home(char *haystack, const char *home_dir)
 		RPMEMD_FATAL("!malloc");
 
 	*pos = '\0';
-	int r = snprintf(buf, haystack_len, "%s%s%s", haystack, home_dir,
+	int r = util_snprintf(buf, haystack_len, "%s%s%s", haystack, home_dir,
 		after);
 	if (r < 0)
-		RPMEMD_FATAL("snprintf: %d", r);
+		RPMEMD_FATAL("!snprintf");
 
 	free(haystack);
 	return buf;
